class DatasetType:
    """All type of dataset
    """
    COLLAR = 'collar'
    SURVEY = 'survey'
    ALTERATION = 'alteration'
    ASSAY = 'assay'
    LITHO = 'litho'
    MINERALISATION = 'mineralisation'